@@ -730,7 +730,6 @@ package Debian::Defoma::Configure;
 use strict;
 #no strict 'subs';
 use POSIX;
-use File::Copy;
 
 use vars qw(@ISA $DEFAULT_PACKAGE $DEFAULT_CATEGORY
 	    @ACCEPT_CATEGORIES $APPINFO);
@@ -960,7 +959,7 @@ sub update_script {
 
     my $suffix = (USERSPACE) ? "udefoma" : "defoma";
 
-    unless (copy($OriginalScripts{$app}, SCRIPTDIR . "/$app.$suffix")) {
+    if (system('cp', $OriginalScripts{$app}, SCRIPTDIR . "/$app.$suffix") != 0) {
 	printe("Failed to copy " . $OriginalScripts{$app} . "to " .
 	       SCRIPTDIR . ".");
 	set_app_info($app, 'error', 1);
@@ -1216,12 +1215,6 @@ sub call_1 {
     return 0 if ($AppInfo{$app}->{ignore_category} &&
 		 exists($AppInfo{$app}->{ignore_category}->{$category}));
 
-    if ($fobj && $com eq 'unregister') {
-	if ($fobj->remove_failed($font, $app)) {
-	    return 0;
-	}
-    }
-
     push(@DefaultPackage, $DEFAULT_PACKAGE);
     push(@DefaultCategory, $DEFAULT_CATEGORY);
 
@@ -1245,6 +1238,12 @@ sub call_1 {
     $DEFAULT_PACKAGE = pop(@DefaultPackage);
     $DEFAULT_CATEGORY = pop(@DefaultCategory);
 
+    if ($fobj && $com eq 'unregister') {
+	if ($fobj->remove_failed($font, $app)) {
+	    return 0;
+	}
+    }
+
     if ($ret && $fobj && $com eq 'register') {
 	$fobj->add_failed($font, $app, $ret);
 	printv("$font: failed to register for package $app, status($ret).");
